@@ -1,3 +1,22 @@
+/* gnome-hint.c - 
+
+   This file is part of the Gnome Library.
+
+   The Gnome Library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public License as
+   published by the Free Software Foundation; either version 2 of the
+   License, or (at your option) any later version.
+   
+   The Gnome Library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
+   
+   You should have received a copy of the GNU Library General Public
+   License along with the Gnome Library; see the file COPYING.LIB.  If not,
+   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
+
 #include <config.h>
 
 #ifndef GNOME_DISABLE_DEPRECATED_SOURCE
@@ -5,7 +24,8 @@
 #undef GNOME_DISABLE_DEPRECATED
 #undef GTK_DISABLE_DEPRECATED
 
-#include <libgnome/libgnome.h>
+#include <glib/gi18n-lib.h>
+#include <libgnome/gnome-macros.h>
 #include <libgnomeui/libgnomeui.h>
 #include <libgnomeui/gnome-hint.h>
 #include <gconf/gconf-client.h>
